@@ -135,8 +135,19 @@ process_keys (gl_list_t keys)
   for (size_t i = 0; i < len; i++)
     pushkey ((size_t) gl_list_get_at (keys, len - i - 1));
 
+  undo_start_sequence ();
   while (term_buf_len () > cur)
-    process_command ();
+    get_and_run_command ();
+  undo_end_sequence ();
+}
+
+static gl_list_t macro_keys;
+
+static bool
+call_macro (void)
+{
+  process_keys (macro_keys);
+  return true;
 }
 
 DEFUN ("call-last-kbd-macro", call_last_kbd_macro)
@@ -151,8 +162,10 @@ A prefix argument serves as a repeat count.
       return leNIL;
     }
 
-  for (int uni = 0; uni < uniarg; ++uni)
-    process_keys (cur_mp->keys);
+  /* FIXME: Call execute-kbd-macro (needs a way to reverse keystrtovec) */
+  /* F_execute_kbd_macro (uniarg, true, leAddDataElement (leNew (NULL), astr_cstr (keyvectostr (cur_mp->keys)), false)); */
+  macro_keys = cur_mp->keys;
+  execute_with_uniarg (true, uniarg, call_macro, NULL);
 }
 END_DEFUN
 
@@ -165,7 +178,10 @@ Execute macro as string of editor command characters.
   STR_INIT (keystr);
   gl_list_t keys = keystrtovec (astr_cstr (keystr));
   if (keys)
-    process_keys (keys);
+    {
+      macro_keys = keys;
+      execute_with_uniarg (true, uniarg, call_macro, NULL);
+    }
   else
     ok = leNIL;
 }
